@@ -17,7 +17,7 @@ class NounPhraseComponent(TransformComponent):
     noun_phrase_regex = "NP: {<NN.*|JJ>*<NN.*>}"
 
     @classmethod
-    def extract_noun_phrases(cls, text: str, nlp: spacy.Language) -> Set[str]:
+    def extract_noun_phrases(cls, text: str, nlp: spacy.Language) -> List[str]:
         """This function takes a string as input and outputs a list of
         noun phrase candidates:
 
@@ -28,7 +28,7 @@ class NounPhraseComponent(TransformComponent):
             nlp (spacy.Language): A spacy language model. Used for POS tagging.
 
         Returns:
-            Set[str]: The noun phrases found in the text.
+            List[str]: The noun phrases found in the text.
         """
         # Clean the text before extracting phrases
         cleaned_text = clean_text(text=text)
@@ -46,19 +46,21 @@ class NounPhraseComponent(TransformComponent):
         trees = parser.parse_sents([doc])
 
         # Storage for all key phrase candidates
-        keyphrase_candidate = set()
+        noun_phrases = []
 
         for tree in trees:
             for subtree in tree.subtrees(
                 filter=lambda t: t.label() == "NP"
             ):  # For each nounphrase
                 # Concatenate the token with a space
-                keyphrase_candidate.add(" ".join(word for word, _ in subtree.leaves()))
+                noun_phrases.append(" ".join(word for word, _ in subtree.leaves()))
 
         # Filter out keyphrases that have more than 5 tokens
-        keyphrase_candidate = {kp for kp in keyphrase_candidate if len(kp.split()) <= 5}
+        noun_phrases = [
+            noun_phrase for noun_phrase in noun_phrases if len(noun_phrase.split()) <= 5
+        ]
 
-        return keyphrase_candidate
+        return noun_phrases
 
     @classmethod
     def transform(
